==> sigenergy2mqtt-2025.7.10.tar.gz: sigenergy2mqtt-2025.7.10/sigenergy2mqtt/config/const.py <==
from typing import Final

SIGENERGY2MQTT_CONFIG: Final = "SIGENERGY2MQTT_CONFIG"
SIGENERGY2MQTT_LOG_LEVEL: Final = "SIGENERGY2MQTT_LOG_LEVEL"
SIGENERGY2MQTT_DEBUG_SENSOR: Final = "SIGENERGY2MQTT_DEBUG_SENSOR"
SIGENERGY2MQTT_SANITY_CHECK_DEFAULT_KW: Final = "SIGENERGY2MQTT_SANITY_CHECK_DEFAULT_KW"

SIGENERGY2MQTT_HASS_DEVICE_NAME_PREFIX: Final = "SIGENERGY2MQTT_HASS_DEVICE_NAME_PREFIX"
SIGENERGY2MQTT_HASS_DISCOVERY_ONLY: Final = "SIGENERGY2MQTT_HASS_DISCOVERY_ONLY"
SIGENERGY2MQTT_HASS_DISCOVERY_PREFIX: Final = "SIGENERGY2MQTT_HASS_DISCOVERY_PREFIX"
SIGENERGY2MQTT_HASS_ENABLED: Final = "SIGENERGY2MQTT_HASS_ENABLED"
SIGENERGY2MQTT_HASS_ENTITY_ID_PREFIX: Final = "SIGENERGY2MQTT_HASS_ENTITY_ID_PREFIX"
SIGENERGY2MQTT_HASS_UNIQUE_ID_PREFIX: Final = "SIGENERGY2MQTT_HASS_UNIQUE_ID_PREFIX"

SIGENERGY2MQTT_MODBUS_ACCHARGER_SLAVE: Final = "SIGENERGY2MQTT_MODBUS_ACCHARGER_SLAVE"
SIGENERGY2MQTT_MODBUS_DCCHARGER_SLAVE: Final = "SIGENERGY2MQTT_MODBUS_DCCHARGER_SLAVE"
SIGENERGY2MQTT_MODBUS_HOST: Final = "SIGENERGY2MQTT_MODBUS_HOST"
SIGENERGY2MQTT_MODBUS_INVERTER_SLAVE: Final = "SIGENERGY2MQTT_MODBUS_INVERTER_SLAVE"
SIGENERGY2MQTT_MODBUS_LOG_LEVEL: Final = "SIGENERGY2MQTT_MODBUS_LOG_LEVEL"
SIGENERGY2MQTT_MODBUS_NO_REMOTE_EMS: Final = "SIGENERGY2MQTT_MODBUS_NO_REMOTE_EMS"
SIGENERGY2MQTT_MODBUS_PORT: Final = "SIGENERGY2MQTT_MODBUS_PORT"
SIGENERGY2MQTT_MODBUS_READ_ONLY: Final = "SIGENERGY2MQTT_MODBUS_READ_ONLY"
SIGENERGY2MQTT_MODBUS_READ_WRITE: Final = "SIGENERGY2MQTT_MODBUS_READ_WRITE"
SIGENERGY2MQTT_MODBUS_WRITE_ONLY: Final = "SIGENERGY2MQTT_MODBUS_WRITE_ONLY"

SIGENERGY2MQTT_MQTT_ANONYMOUS: Final = "SIGENERGY2MQTT_MQTT_ANONYMOUS"
SIGENERGY2MQTT_MQTT_BROKER: Final = "SIGENERGY2MQTT_MQTT_BROKER"
SIGENERGY2MQTT_MQTT_LOG_LEVEL: Final = "SIGENERGY2MQTT_MQTT_LOG_LEVEL"
SIGENERGY2MQTT_MQTT_PASSWORD: Final = "SIGENERGY2MQTT_MQTT_PASSWORD"
SIGENERGY2MQTT_MQTT_PORT: Final = "SIGENERGY2MQTT_MQTT_PORT"
SIGENERGY2MQTT_MQTT_USERNAME: Final = "SIGENERGY2MQTT_MQTT_USERNAME"

SIGENERGY2MQTT_PVOUTPUT_API_KEY: Final = "SIGENERGY2MQTT_PVOUTPUT_API_KEY"
SIGENERGY2MQTT_PVOUTPUT_CONSUMPTION: Final = "SIGENERGY2MQTT_PVOUTPUT_CONSUMPTION"
SIGENERGY2MQTT_PVOUTPUT_ENABLED: Final = "SIGENERGY2MQTT_PVOUTPUT_ENABLED"
SIGENERGY2MQTT_PVOUTPUT_INTERVAL: Final = "SIGENERGY2MQTT_PVOUTPUT_INTERVAL"
SIGENERGY2MQTT_PVOUTPUT_LOG_LEVEL: Final = "SIGENERGY2MQTT_PVOUTPUT_LOG_LEVEL"
SIGENERGY2MQTT_PVOUTPUT_SYSTEM_ID: Final = "SIGENERGY2MQTT_PVOUTPUT_SYSTEM_ID"
SIGENERGY2MQTT_PVOUTPUT_TESTING: Final = "SIGENERGY2MQTT_PVOUTPUT_TESTING"

SIGENERGY2MQTT_SCAN_INTERVAL_LOW: Final = "SIGENERGY2MQTT_SCAN_INTERVAL_LOW"
SIGENERGY2MQTT_SCAN_INTERVAL_MEDIUM: Final = "SIGENERGY2MQTT_SCAN_INTERVAL_MEDIUM"
SIGENERGY2MQTT_SCAN_INTERVAL_HIGH: Final = "SIGENERGY2MQTT_SCAN_INTERVAL_HIGH"
SIGENERGY2MQTT_SCAN_INTERVAL_REALTIME: Final = "SIGENERGY2MQTT_SCAN_INTERVAL_REALTIME"

SIGENERGY2MQTT_SMARTPORT_ENABLED: Final = "SIGENERGY2MQTT_SMARTPORT_ENABLED"
SIGENERGY2MQTT_SMARTPORT_HOST: Final = "SIGENERGY2MQTT_SMARTPORT_HOST"
SIGENERGY2MQTT_SMARTPORT_MODULE_NAME: Final = "SIGENERGY2MQTT_SMARTPORT_MODULE_NAME"
SIGENERGY2MQTT_SMARTPORT_MQTT_GAIN: Final = "SIGENERGY2MQTT_SMARTPORT_MQTT_GAIN"
SIGENERGY2MQTT_SMARTPORT_MQTT_TOPIC: Final = "SIGENERGY2MQTT_SMARTPORT_MQTT_TOPIC"
SIGENERGY2MQTT_SMARTPORT_PASSWORD: Final = "SIGENERGY2MQTT_SMARTPORT_PASSWORD"
SIGENERGY2MQTT_SMARTPORT_PV_POWER: Final = "SIGENERGY2MQTT_SMARTPORT_PV_POWER"
SIGENERGY2MQTT_SMARTPORT_USERNAME: Final = "SIGENERGY2MQTT_SMARTPORT_USERNAME"

==> sigenergy2mqtt-2025.8.5.tar.gz: sigenergy2mqtt-2025.8.5/sigenergy2mqtt/config/const.py <==
from typing import Final

SIGENERGY2MQTT_CONFIG: Final = "SIGENERGY2MQTT_CONFIG"
SIGENERGY2MQTT_LOG_LEVEL: Final = "SIGENERGY2MQTT_LOG_LEVEL"
SIGENERGY2MQTT_DEBUG_SENSOR: Final = "SIGENERGY2MQTT_DEBUG_SENSOR"
SIGENERGY2MQTT_SANITY_CHECK_DEFAULT_KW: Final = "SIGENERGY2MQTT_SANITY_CHECK_DEFAULT_KW"
SIGENERGY2MQTT_NO_METRICS: Final = "SIGENERGY2MQTT_NO_METRICS"

SIGENERGY2MQTT_HASS_DEVICE_NAME_PREFIX: Final = "SIGENERGY2MQTT_HASS_DEVICE_NAME_PREFIX"
SIGENERGY2MQTT_HASS_DISCOVERY_ONLY: Final = "SIGENERGY2MQTT_HASS_DISCOVERY_ONLY"
SIGENERGY2MQTT_HASS_DISCOVERY_PREFIX: Final = "SIGENERGY2MQTT_HASS_DISCOVERY_PREFIX"
SIGENERGY2MQTT_HASS_ENABLED: Final = "SIGENERGY2MQTT_HASS_ENABLED"
SIGENERGY2MQTT_HASS_ENTITY_ID_PREFIX: Final = "SIGENERGY2MQTT_HASS_ENTITY_ID_PREFIX"
SIGENERGY2MQTT_HASS_UNIQUE_ID_PREFIX: Final = "SIGENERGY2MQTT_HASS_UNIQUE_ID_PREFIX"
SIGENERGY2MQTT_HASS_USE_SIMPLIFIED_TOPICS: Final = "SIGENERGY2MQTT_HASS_USE_SIMPLIFIED_TOPICS"

SIGENERGY2MQTT_MODBUS_ACCHARGER_DEVICE_ID: Final = "SIGENERGY2MQTT_MODBUS_ACCHARGER_DEVICE_ID"
SIGENERGY2MQTT_MODBUS_ACCHARGER_SLAVE: Final = "SIGENERGY2MQTT_MODBUS_ACCHARGER_SLAVE"  # Deprecated, use SIGENERGY2MQTT_MODBUS_ACCHARGER_DEVICE_ID
SIGENERGY2MQTT_MODBUS_DCCHARGER_DEVICE_ID: Final = "SIGENERGY2MQTT_MODBUS_DCCHARGER_DEVICE_ID"
SIGENERGY2MQTT_MODBUS_DCCHARGER_SLAVE: Final = "SIGENERGY2MQTT_MODBUS_DCCHARGER_SLAVE"  # Deprecated, use SIGENERGY2MQTT_MODBUS_DCCHARGER_DEVICE_ID
SIGENERGY2MQTT_MODBUS_HOST: Final = "SIGENERGY2MQTT_MODBUS_HOST"
SIGENERGY2MQTT_MODBUS_INVERTER_DEVICE_ID: Final = "SIGENERGY2MQTT_MODBUS_INVERTER_DEVICE_ID"
SIGENERGY2MQTT_MODBUS_INVERTER_SLAVE: Final = "SIGENERGY2MQTT_MODBUS_INVERTER_SLAVE"  # Deprecated, use SIGENERGY2MQTT_MODBUS_INVERTER_DEVICE_ID
SIGENERGY2MQTT_MODBUS_LOG_LEVEL: Final = "SIGENERGY2MQTT_MODBUS_LOG_LEVEL"
SIGENERGY2MQTT_MODBUS_NO_REMOTE_EMS: Final = "SIGENERGY2MQTT_MODBUS_NO_REMOTE_EMS"
SIGENERGY2MQTT_MODBUS_PORT: Final = "SIGENERGY2MQTT_MODBUS_PORT"
SIGENERGY2MQTT_MODBUS_READ_ONLY: Final = "SIGENERGY2MQTT_MODBUS_READ_ONLY"
SIGENERGY2MQTT_MODBUS_READ_WRITE: Final = "SIGENERGY2MQTT_MODBUS_READ_WRITE"
SIGENERGY2MQTT_MODBUS_WRITE_ONLY: Final = "SIGENERGY2MQTT_MODBUS_WRITE_ONLY"

SIGENERGY2MQTT_MQTT_ANONYMOUS: Final = "SIGENERGY2MQTT_MQTT_ANONYMOUS"
SIGENERGY2MQTT_MQTT_BROKER: Final = "SIGENERGY2MQTT_MQTT_BROKER"
SIGENERGY2MQTT_MQTT_LOG_LEVEL: Final = "SIGENERGY2MQTT_MQTT_LOG_LEVEL"
SIGENERGY2MQTT_MQTT_PASSWORD: Final = "SIGENERGY2MQTT_MQTT_PASSWORD"
SIGENERGY2MQTT_MQTT_PORT: Final = "SIGENERGY2MQTT_MQTT_PORT"
SIGENERGY2MQTT_MQTT_USERNAME: Final = "SIGENERGY2MQTT_MQTT_USERNAME"

SIGENERGY2MQTT_PVOUTPUT_API_KEY: Final = "SIGENERGY2MQTT_PVOUTPUT_API_KEY"
SIGENERGY2MQTT_PVOUTPUT_CONSUMPTION: Final = "SIGENERGY2MQTT_PVOUTPUT_CONSUMPTION"
SIGENERGY2MQTT_PVOUTPUT_ENABLED: Final = "SIGENERGY2MQTT_PVOUTPUT_ENABLED"
SIGENERGY2MQTT_PVOUTPUT_INTERVAL: Final = "SIGENERGY2MQTT_PVOUTPUT_INTERVAL"  # Deprecated, the Status Interval is now determined from the settings on pvoutput.org
SIGENERGY2MQTT_PVOUTPUT_LOG_LEVEL: Final = "SIGENERGY2MQTT_PVOUTPUT_LOG_LEVEL"
SIGENERGY2MQTT_PVOUTPUT_SYSTEM_ID: Final = "SIGENERGY2MQTT_PVOUTPUT_SYSTEM_ID"
SIGENERGY2MQTT_PVOUTPUT_TEMP_TOPIC: Final = "SIGENERGY2MQTT_PVOUTPUT_TEMP_TOPIC"

SIGENERGY2MQTT_SCAN_INTERVAL_LOW: Final = "SIGENERGY2MQTT_SCAN_INTERVAL_LOW"
SIGENERGY2MQTT_SCAN_INTERVAL_MEDIUM: Final = "SIGENERGY2MQTT_SCAN_INTERVAL_MEDIUM"
SIGENERGY2MQTT_SCAN_INTERVAL_HIGH: Final = "SIGENERGY2MQTT_SCAN_INTERVAL_HIGH"
SIGENERGY2MQTT_SCAN_INTERVAL_REALTIME: Final = "SIGENERGY2MQTT_SCAN_INTERVAL_REALTIME"

SIGENERGY2MQTT_SMARTPORT_ENABLED: Final = "SIGENERGY2MQTT_SMARTPORT_ENABLED"
SIGENERGY2MQTT_SMARTPORT_HOST: Final = "SIGENERGY2MQTT_SMARTPORT_HOST"
SIGENERGY2MQTT_SMARTPORT_MODULE_NAME: Final = "SIGENERGY2MQTT_SMARTPORT_MODULE_NAME"
SIGENERGY2MQTT_SMARTPORT_MQTT_GAIN: Final = "SIGENERGY2MQTT_SMARTPORT_MQTT_GAIN"
SIGENERGY2MQTT_SMARTPORT_MQTT_TOPIC: Final = "SIGENERGY2MQTT_SMARTPORT_MQTT_TOPIC"
SIGENERGY2MQTT_SMARTPORT_PASSWORD: Final = "SIGENERGY2MQTT_SMARTPORT_PASSWORD"
SIGENERGY2MQTT_SMARTPORT_PV_POWER: Final = "SIGENERGY2MQTT_SMARTPORT_PV_POWER"
SIGENERGY2MQTT_SMARTPORT_USERNAME: Final = "SIGENERGY2MQTT_SMARTPORT_USERNAME"
